.. code-block:: bash

   Usage: nessie diff [OPTIONS] FROM_REF TO_REF
   
     Show diff between two given references.
   
     from_ref/to_ref: name of branch or tag to use to show the diff
   
     Examples:
   
         nessie diff from_ref to_ref -> show diff between 'from_ref' and 'to_ref'
   
   Options:
     --help  Show this message and exit.
   
   

